aboutsummaryrefslogtreecommitdiffstats
path: root/gcc-4.9/libgfortran/generated/pack_c4.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc-4.9/libgfortran/generated/pack_c4.c')
-rw-r--r--gcc-4.9/libgfortran/generated/pack_c4.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gcc-4.9/libgfortran/generated/pack_c4.c b/gcc-4.9/libgfortran/generated/pack_c4.c
index f17d35abf..36a9f941c 100644
--- a/gcc-4.9/libgfortran/generated/pack_c4.c
+++ b/gcc-4.9/libgfortran/generated/pack_c4.c
@@ -167,8 +167,8 @@ pack_c4 (gfc_array_c4 *ret, const gfc_array_c4 *array,
ret->offset = 0;
- /* xmalloc allocates a single byte for zero size. */
- ret->base_addr = xmalloc (sizeof (GFC_COMPLEX_4) * total);
+ /* xmallocarray allocates a single byte for zero size. */
+ ret->base_addr = xmallocarray (total, sizeof (GFC_COMPLEX_4));
if (total == 0)
return;